/*
 * xyz-mIoT embedded sensors [HDC2010, HALL + Vbat & Vraw] reading software example - v1.0 / 20180709. Support software example for xyz-mIoT v2.09 by itbrainpower.net
 * 
 * compatible with xyz-mIoT boards having PN with 1xxxxxx suffix [HDC2010 integrated] and x1xxxxx suffix [HALL integrated].
 * Vbat and Vraw reading is compatible with all xyz-mIoT variants.
 * 
 * HDC2010 temperature and humidity (pulling at 1 second and confort zone -interrupt based) reading example - based on software provided by Texas Instruments 
 * Incorporated. Read credists bellow.
 * HALL example, interrupt based.
 * Vbat and Vraw reading example. Measurments are made via ATSAMD21D analog ports A4 and A5.
 * 
 * You are legaly entitled to use this SOFTWARE ONLY IN CONJUNCTION WITH xyz-mIoT DEVICES USAGE. Modifications, derivates and redistribution 
 * of this software must include unmodified this COPYRIGHT NOTICE. You can redistribute this SOFTWARE and/or modify it under the terms 
 * of this COPYRIGHT NOTICE. Any other usage may be permited only after written notice of Dragos Iosub / R&D Software Solutions srl.
 * 
 * This SOFTWARE is distributed is provide "AS IS" in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE.
 *  
 * Dragos Iosub, Bucharest 2018.
 * https://itbrainpower.net
 */

/*
 * HDC2010.ino
 * Created: August 1st 2017
 * This sketch is released AS-IS into the public domain, no guarantee or warranty is given.
 * This Code is not supported by Texas Instruments.
 * 
 * Description: This sketch configures the HDC2010 to monitor for a specific temperature 
 * and humidity range, with regular one second samples. The temperature and humidity readings
 * of the device are printed to a standard 16x2 LCD display. When the threshold values are
 * exceeded, the LCD will also have "ALT" printed in the bottom right corner. The schematic 
 * for this example is included alongside the HDC2010 Arduino Source Code.
 * 
 * Copyright (C) 2017 Texas Instruments Incorporated - http://www.ti.com/ 
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

#include <HDC2010.h>
/*following definitions [used in software] are placed in xyz-mIoT variant.h
HDC2010 related:
- I2C_HDC2010_ADDRESS 0x40        //default HDC2010 I2C address
- HDC2010_INTERRUPT_PIN 5         //pin mapped as IRQ for HDC2010. Confort zone example. Read HDC2010 documentation for more.

HALL related:
- HALL_IRQ_PIN 6                  //IRQ used for HALL. Or read this pin value for pulling mode.
- HALL_PULLUP_PIN 25              //pullup this pin in order to enable HALL sensor readings.

Voltage measurments:
- VbatPin A5
- VrawPin A4

Modem control assigned digital pis:
- CTRL_PIN_MODEMPOWER         38        //Digital pin used enable/disable modem power
- lprCtrlPIN                  26        //Digital pin used to control the modem on/off
- CTRL_PIN_GNSSANTENNAPOWER   4         //Digital pin used to control the active GNSS antenna power
*/

HDC2010 sensor(I2C_HDC2010_ADDRESS);


float temperature = 0, humidity = 0;
float Vbat = 0, Vraw = 0;
int alarmTHS = 0;
int alarmHALL = 0;

void setup() {
  pinMode(LED_BUILTIN, OUTPUT);
  delay(10000);
  SerialUSB.begin(115200);
  delay(5000);
  SerialUSB.println("test xyz-mIoT shield embedded HDC2010 and HALL sensors. Voltage measurments too.");

  // Initialize HDC2010(THS) I2C communication
  sensor.begin();
    
  // Begin with a HDC2010(THS) reset
  sensor.reset();

  // Set up HDC2010(THS) temperature offset, if needed
  sensor.setTemperatureOffset(0b11010111);    //-6.64 degrees Celsius - determine and set your, see definitions and HDC2010 datasheet

  
  // Set up HDC2010(THS) comfort zone
  sensor.setHighTemp(28);         // High temperature of 28C
  sensor.setLowTemp(22);          // Low temperature of 22C
  sensor.setHighHumidity(55);     // High humidity of 55%
  sensor.setLowHumidity(40);      // Low humidity of 40%
  

  // Configure HDC2010(THS) interrupt mode
  sensor.enableInterrupt();                   // Enable the Interrupt/DRDY pin
  sensor.enableThresholdInterrupt();          // Enable Interrupt triggering based on comfort zone
  sensor.setInterruptPolarity(ACTIVE_HIGH);   // Set Interrupt pin to Active High
  sensor.setInterruptMode(COMPARATOR_MODE);   // Set Interrupt to return to inactive state when in bounds

  
  // Configure Measurements
  sensor.setMeasurementMode(TEMP_AND_HUMID);  // Set measurements to temperature and humidity
  sensor.setRate(ONE_HZ);                     // Set measurement frequency to 1 Hz
  sensor.setTempRes(FOURTEEN_BIT);
  sensor.setHumidRes(FOURTEEN_BIT);

  
  // Configure HDC2010(THS) Interrupt Pin
  pinMode(HDC2010_INTERRUPT_PIN, INPUT);                 // HDC2010_INTERRUPT_PIN will be the interrupt input
  attachInterrupt(digitalPinToInterrupt(HDC2010_INTERRUPT_PIN), alertTHS, CHANGE);  //ISR "alert" will be triggered by changes in HDC2010_INTERRUPT_PIN

  // Configure HALL sensor Interrupt Pin
  pinMode(HALL_IRQ_PIN, INPUT_PULLUP);                   // HALL_IRQ_PIN will be the interrupt input
  attachInterrupt(digitalPinToInterrupt(HALL_IRQ_PIN), alertHALL, CHANGE);  //ISR "alert" will be triggered by changes in HALL_IRQ_PIN

  // Enable the HALL sensor
  pinMode(HALL_PULLUP_PIN, OUTPUT);                     // enable HALL sensor 
  digitalWrite(HALL_PULLUP_PIN, HIGH);                  // enable HALL sensor

  //remove comment on following lines if you like performe the tests with the modem enabled. 
  /*
  delay(1000);
  pinMode(ENABLEMODEMPOWER, OUTPUT);
  pinMode(lprCtrlPIN, OUTPUT);
  pinMode(ENABLEGNSSPOWER, OUTPUT); 
  digitalWrite(ENABLEMODEMPOWER, HIGH);               // enable power to modem   
  digitalWrite(lprCtrlPIN, LOW);                      // power ON the modem
  delay(2000);   
  digitalWrite(ENABLEGNSSPOWER, LOW);                 // enable GNSS antenna powering circuitry   
  */
  
  delay(1000);

  //begin HDC2010 sensor measuring
  sensor.triggerMeasurement();
}

void loop() {
  // read temperature and humidity
  temperature = sensor.readTemp();
  humidity = sensor.readHumidity();

  SerialUSB.print("TEMP(C): ");
  SerialUSB.println(temperature);

  SerialUSB.print("%RH: ");
  SerialUSB.println(humidity);

  //read voltage
  Vbat=analogRead(VbatPin)*1000*0.0065344650650891/*0.0063636363636364*/;      //8bit read
  Vraw=analogRead(VrawPin)*1000*0.0102016129032258;      //8bit read

  SerialUSB.print("Vraw: ");
  SerialUSB.print(Vraw);
  SerialUSB.println(" mV");

  SerialUSB.print("Vbat: ");
  SerialUSB.print(Vbat);
  SerialUSB.println(" mV");


  // Wait 1 second for the next reading
  delay(1000);
  
}

// ISR to print alert on "CONFORT ZONE"
void alertTHS(void) {

  //Load the current state of the THS Alert Pin to the alarmTHS variable
  alarmTHS = digitalRead(HDC2010_INTERRUPT_PIN);

  //If the alert pin was high, print ALT
  if (alarmTHS)
    {
      SerialUSB.println("OUTSIDE");
      digitalWrite(LED_BUILTIN, HIGH);   // turn the LED on (HIGH is the voltage level)
    }
  //Otherwise overwrite "ALT" with spaces
  else
    {
      SerialUSB.println("INSIDE");
      digitalWrite(LED_BUILTIN, LOW);   // turn the LED on (LOW is the voltage level)
    }

  
}

void alertHALL(void) {

  //Load the current state of the HALL Alert Pin to the alarmHALL variable
  alarmHALL = digitalRead(HALL_IRQ_PIN);

  //If the alert pin was high, print ALT
  if (alarmHALL)
    {
      digitalWrite(LED_BUILTIN, HIGH);   // turn the LED on (HIGH is the voltage level)
    }
  //Otherwise overwrite "ALT" with spaces
  else
    {
      digitalWrite(LED_BUILTIN, LOW);   // turn the LED on (LOW is the voltage level)
    }
  
}

